@@ -22,21 +22,38 @@ Copyright_License {
 */
 
 #include "../Timer.hpp"
+#include "Queue.hpp"
+#include "Android/Main.hpp"
 
 void
-Timer::Schedule(unsigned ms)
+Timer::Schedule(unsigned _ms)
 {
-  Cancel();
+  if (queued.exchange(false))
+    event_queue->CancelTimer(*this);
 
-  timer = new AndroidTimer(*this, ms);
+  enabled.store(true);
+  ms = _ms;
+
+  if (!queued.exchange(true))
+    event_queue->AddTimer(*this, ms);
 }
 
 void
 Timer::Cancel()
 {
-  if (!IsActive())
+  if (enabled.exchange(false) && queued.exchange(false))
+    event_queue->CancelTimer(*this);
+}
+
+void
+Timer::Invoke()
+{
+  if (!queued.exchange(false))
+    /* was cancelled by another thread */
     return;
 
-  timer->disable();
-  timer = NULL;
+  OnTimer();
+
+  if (enabled.load() && !queued.exchange(true))
+    event_queue->AddTimer(*this, ms);
 }
