@@ -29,11 +29,21 @@ Copyright_License {
 #include "Util/Macros.hpp"
 #include "LocalPath.hpp"
 #include "Dialogs/TimeEntry.hpp"
+#include "Dialogs/GeoPointEntry.hpp"
+#include "Time/RoughTime.hpp"
 
 void VisitDataFiles(const TCHAR* filter, File::Visitor &visitor) {}
 
 bool
-TimeEntryDialog(const TCHAR *caption, RoughTime &value, bool nullable)
+TimeEntryDialog(const TCHAR *caption, RoughTime &value,
+                RoughTimeDelta time_zone, bool nullable)
+{
+  return false;
+}
+
+bool
+GeoPointEntryDialog(const TCHAR *caption, GeoPoint &value,
+                    bool nullable)
 {
   return false;
 }
@@ -42,5 +52,5 @@ static void
 Main()
 {
   TCHAR text[64] = _T("");
-  dlgTextEntryShowModal(text, ARRAY_SIZE(text), _T("The caption"));
+  TextEntryDialog(text, ARRAY_SIZE(text), _T("The caption"));
 }
